# -*- coding: utf-8 -*-
# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2020 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT


# TODO: convert this file into python package
#       and move logic of modules manipulations here
import json
import os

from clwpos.utils import acquire_lock, uid_by_name
from clcommon.lib.cledition import is_cl_solo_edition
from clcommon.cpapi import cpusers
from clwpos.constants import CLWPOS_VAR_DIR, ALLOWED_MODULES_JSON, CLWPOS_UIDS_PATH, CLWPOS_SOLO_PATH

ALLOWED_MODULES_CONFIG_VERSION = 1

# TODO: this part does not support shared environment
ALLOWED_MODULES_CONFIG = "/var/clwpos/solo/modules_allowed.json"


OBJECT_CACHE_MODULE = "object_cache"
ALL_OPTIMIZATION_MODULES = [
    OBJECT_CACHE_MODULE
]


def is_module_allowed_for_user(module=OBJECT_CACHE_MODULE):
    """
    Checks whether <module> enabled for at least one user
    """
    if is_cl_solo_edition(skip_jwt_check=True):
        data = get_all_modules_data()
        return data.get(module)
    else:
        users = list(cpusers())
        for username in users:
            uid = uid_by_name(username)
            if not uid:
                continue
            module_path = os.path.join(CLWPOS_UIDS_PATH, str(uid), ALLOWED_MODULES_JSON)
            if get_all_modules_data(module_path).get(module):
                return True
        return False


def get_allowed_modules() -> list:
    """
    Reads configuration file (which is manipulated by admin)
    and returns only that modules which are allowed
    to be enabled by endusers.
    @return: list of module unique ids
    """
    if not os.path.exists(ALLOWED_MODULES_CONFIG):
        return ALL_OPTIMIZATION_MODULES

    # TODO: malformed config is breaking whole tool: LU-2647
    with open(ALLOWED_MODULES_CONFIG) as file:
        return [
            module
            for module, is_allowed in json.load(file)["modules"].items()
            if is_allowed
        ]


def get_all_modules_data(modules_json_path=ALLOWED_MODULES_CONFIG):
    """
    Reads modules statuses from .json or returns defaults
    """
    if not os.path.exists(modules_json_path):
        data = {
            "version": str(ALLOWED_MODULES_CONFIG_VERSION),
            "modules": dict.fromkeys(ALL_OPTIMIZATION_MODULES, True),
        }
        return data["modules"]
    with acquire_lock(modules_json_path):
        with open(modules_json_path, "r") as file:
            return json.load(file)["modules"]
