#!/opt/alt/python37/bin/python3.7 -bb
# -*- coding: utf-8 -*-

# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2019 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT
from __future__ import absolute_import

import json
import subprocess
import sys
from clcommon.cpapi import docroot

from clcommon.lib.whmapi_lib import WhmApiRequest
import pwd

from clwpos.utils import demote
from cpanel_user_disable_caching import check_and_disable_cache
checked_users = set()


def get_user_uid_and_gid(user: str):
    pw = pwd.getpwnam(user)
    return pw.pw_uid, pw.pw_gid


if '__main__' == __name__:
    # If admin triggers this function we are checking all affected users wps for compatibility
    # Need optimization in future
    # Hook is triggered by events
    #   Web - WHM: -> MultiPHP Manager: -> User Domain Settings
    #   CLI - Whostmgr Lang::PHP::set_vhost_versions post

    args = json.loads(sys.stdin.read())
    args_data = args['data']

    domains_affected = [v for k, v in args_data.items() if 'vhost' in k]
    users_affected = set()

    # Getting which users to check for
    for domain in domains_affected:
        _, username = docroot(domain)
        users_affected.add(username)

    php_versions = WhmApiRequest('php_get_vhost_versions').call()

    for v in php_versions['versions']:
        user_name = v['account']

        # Check user only once
        if user_name not in checked_users and user_name in users_affected:
            checked_users.add(user_name)
            uid, gid = get_user_uid_and_gid(user_name)

            cmd = '/usr/bin/clwpos-user get'
            result = subprocess.run(cmd, shell=True, text=True, capture_output=True, preexec_fn=demote(uid, gid)).stdout

            for data in json.loads(result)['docroots']:
                domain_name = data['domains'][0]
                check_and_disable_cache(domain_name, data['wps'], (uid, gid))
