#!/opt/alt/python37/bin/python3.7 -bb
# -*- coding: utf-8 -*-

# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2019 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT
from __future__ import absolute_import

import json
import sys
import subprocess

# This hook will be triggered in case of user changing php version from cpanel for any of wp
# This module will disable object_cache if not supported php_version or php-fpm handler exists in users wordpress sites
# Hook is triggered by events
#   Web - Cpanel: -> MultiPHP Manager
#   CLI - Cpanel UAPI::LangPHP::php_set_vhost_versions post
from clwpos.utils import demote

MODULE = 'object_cache'


def disable_cache(domain: str, wp_path: str, user_id: list = None):
    """Disable cache for specified domain and wp_path
    Arguments:
        domain: name of domain ex: domain.com
        wp_path: path to wordpress site
        user_id: List of uid and gid
    """

    __cmd = f'/usr/bin/clwpos-user disable --domain={domain} --wp-path={wp_path} --module={MODULE}'

    if user_id:
        subprocess.run(__cmd, capture_output=True, text=True, shell=True, preexec_fn=demote(*user_id))
    else:
        subprocess.run(__cmd, capture_output=True, text=True, shell=True)


def check_and_disable_cache(domain: str, wps: list, user_id: list = None):
    """Check for and disable object cache if incompatibility issues found for specified wp
    Arguments:
        domain: name of domain ex: domain.com
        wps: list of wps data
        user_id: List of uid and gid
    """
    for wp in wps:
        wp_path = wp['path']
        issues = wp.get('modules', {}).get('object_cache', {}).get('issues', [])
        incompatibilities_only = [issue for issue in issues if issue['type'] == 'incompatibility']
        if incompatibilities_only:
            disable_cache(domain, wp_path, user_id)


if '__main__' == __name__:

    args = json.loads(sys.stdin.read())

    user_name = args['data']['user']

    cmd = '/usr/bin/clwpos-user get'
    result = subprocess.run(cmd, shell=True, text=True, capture_output=True).stdout

    for data in json.loads(result)['docroots']:
        domain_name = data['domains'][0]
        check_and_disable_cache(domain_name, data['wps'])
